@@ -467,26 +467,23 @@ class Components(object):
         if hosting_component_pin2:
             h_pin2 = self._get_edb_pin_from_pin_name(hosting_component, hosting_component_pin2)
             h_pin2_pos = self.get_pin_position(h_pin2)
-        #
-        vector = [h_pin1_pos[0] - m_pin1_pos[0], h_pin1_pos[1] - m_pin1_pos[1]]
+
+        if flipped:
+            m_pin1_pos[1] *= -1.0
+            m_pin2_pos[1] *= -1.0
+
         vector1 = GeometryOperators.v_points(m_pin1_pos, m_pin2_pos)
         vector2 = GeometryOperators.v_points(h_pin1_pos, h_pin2_pos)
-        multiplier = 1
-        if flipped:
-            multiplier = -1
-        vector1[1] = multiplier * vector1[1]
 
         rotation = GeometryOperators.v_angle_sign_2D(vector1, vector2, False)
-        if rotation != 0.0:
-            x_v2 = m_pin1_pos[0] * math.cos(rotation) + multiplier * m_pin1_pos[1] * math.sin(rotation)
-            y_v2 = -1 * m_pin1_pos[0] * math.sin(rotation) + multiplier * m_pin1_pos[1] * math.cos(rotation)
-            new_vector = [x_v2, y_v2]
-            vector = [h_pin1_pos[0] - new_vector[0], h_pin1_pos[1] - new_vector[1]]
+        offset_from_x = m_pin1_pos[0] * math.cos(rotation) + m_pin1_pos[1] * math.sin(rotation)
+        offset_from_y = -1 * m_pin1_pos[0] * math.sin(rotation) + m_pin1_pos[1] * math.cos(rotation)
+        vector = [h_pin1_pos[0] - offset_from_x, h_pin1_pos[1] - offset_from_y]
 
-        if vector:
-            solder_ball_height = self.get_solder_ball_height(mounted_component)
+        solder_ball_height = self.get_solder_ball_height(mounted_component)
+        if isinstance(solder_ball_height, float):
             return True, vector, rotation, solder_ball_height
-        self._logger.warning("Failed to compute vector.")
+        self._logger.warning("Failed to compute solder ball height.")
         return False, [0, 0], 0, 0
 
     @pyaedt_function_handler()
@@ -1012,18 +1009,18 @@ class Components(object):
         return False
 
     @pyaedt_function_handler()
-    def set_solder_ball(self, component="", sball_diam="100um", sball_height="150um"):
+    def set_solder_ball(self, component, sball_diam="", sball_height=""):
         """Set cylindrical solder balls on a given component.
 
         Parameters
         ----------
-        componentname : str or EDB component
+        component : str or EDB component
             Name of the discret component.
 
-        sball_diam  : str, float
+        sball_diam  : str, float, optional
             Diameter of the solder ball.
 
-        sball_height : str, float
+        sball_height : str, float, optional
             Height of the solder ball.
 
         Returns
@@ -1041,10 +1038,19 @@ class Components(object):
         """
         if not isinstance(component, self._edb.Cell.Hierarchy.Component):
             edb_cmp = self.get_component_by_name(component)
+            cmp = self.components[component]
         else:
             edb_cmp = component
+            cmp = self.components[edb_cmp.GetName()]
         if edb_cmp:
             cmp_type = edb_cmp.GetComponentType()
+            if bool(not sball_diam + sball_height):
+                pin1 = list(cmp.pins.values())[0].pin
+                pin_layers = pin1.GetPadstackDef().GetData().GetLayerNames()
+                pad_params = self._padstack.get_pad_parameters(pin=pin1, layername=pin_layers[0], pad_type=0)
+                _sb_diam = min([self._get_edb_value(val).ToDouble() for val in pad_params[1]])
+                sball_diam = _sb_diam
+                sball_height = sball_diam
             if cmp_type == self._edb.Definition.ComponentType.IC:
                 ic_cmp_property = edb_cmp.GetComponentProperty().Clone()
                 ic_die_prop = ic_cmp_property.GetDieProperty().Clone()
@@ -1086,7 +1092,7 @@ class Components(object):
                 other_port_prop = other_cmp_prop.GetPortProperty().Clone()
                 other_port_prop.SetReferenceSizeAuto(True)
                 other_cmp_prop.SetPortProperty(other_port_prop)
-                edb_cmp.SetComponentProperty(other_port_prop)
+                edb_cmp.SetComponentProperty(other_cmp_prop)
             else:
                 return False
         else:
